==> rk.ClusterAnalysis_0.01-0.tar.gz: rk.ClusterAnalysis/inst/rkward/plugins/ModelbasedCA.js <==
// this code was generated using the rkwarddev package.
//perhaps don't make changes here, but in the rkwarddev script instead!

function preprocess(){
	// add requirements etc. here
	echo("require(mclust)\n");
}

function calculate(){
	// read in variables from dialog
	var vrslDtmtrxrd = getValue("vrsl_Dtmtrxrd");
	var chcRmvmssng = getValue("chc_Rmvmssng");
	var chcStdrdzvl = getValue("chc_Stdrdzvl");
	var spnMxnmbrfc = getValue("spn_Mxnmbrfc");
	var chcPltrslts = getValue("chc_Pltrslts");
	var svbSvrsltst = getValue("svb_Svrsltst");
	var radPlottype = getValue("rad_Plottype");

	// the R code to be evaluated
	if(chcRmvmssng) {
		echo("\t# Listwise removal of missings\n\t" + vrslDtmtrxrd + " <- na.omit(" + vrslDtmtrxrd + ")\n");
	} else {}
	if(chcStdrdzvl) {
		echo("\t# Standardizing values\n\t" + vrslDtmtrxrd + " <- scale(" + vrslDtmtrxrd + ")\n");
	} else {}
	echo("\t# Model based CA\n\tclust.m.result <- Mclust(data=" + vrslDtmtrxrd);
	if(spnMxnmbrfc != 9) {
		echo(",\n\t\tG=1:" + spnMxnmbrfc + "\n\t");
	} else {}
	echo(")\n\n");
}

function printout(){
	// all the real work is moved to a custom defined function doPrintout() below
	// true in this case means: We want all the headers that should be printed in the output:
	doPrintout(true);
}

function preview(){
	preprocess();
	calculate();
	doPrintout(false);
}

function doPrintout(full){
	// read in variables from dialog
	var vrslDtmtrxrd = getValue("vrsl_Dtmtrxrd");
	var chcRmvmssng = getValue("chc_Rmvmssng");
	var chcStdrdzvl = getValue("chc_Stdrdzvl");
	var spnMxnmbrfc = getValue("spn_Mxnmbrfc");
	var chcPltrslts = getValue("chc_Pltrslts");
	var svbSvrsltst = getValue("svb_Svrsltst");
	var radPlottype = getValue("rad_Plottype");

	// create the plot
	if(full) {
		echo("rk.header(\"Model based CA results\", level=1)\n");
	} else {}

	if(chcPltrslts) {
		if(full) {
	echo("rk.graph.on()\n");
} else {}
echo("\ttry({\n\t\tplot(clust.m.result,\n\t\t\tdata=" + vrslDtmtrxrd + ",\n\t\t\twhat=\"" + radPlottype + "\"");
echo(")\n\t})\n");
if(full) {
	echo("rk.graph.off()\n");
} else {}
	} else {}
	echo("\trk.print(clust.m.result)\n");

	// left over from the printout function

	var svbSvrsltst = getValue("svb_Svrsltst");
	var svbSvrsltstActive = getValue("svb_Svrsltst.active");
	var svbSvrsltstParent = getValue("svb_Svrsltst.parent");
	if(svbSvrsltstActive) {
		echo("assign(\"" + svbSvrsltst + "\", clust.m.result, envir=" + svbSvrsltstParent + ")\n");
	} else {}


}

==> rk.ClusterAnalysis_0.01-1.tar.gz: rk.ClusterAnalysis/inst/rkward/plugins/ModelbasedCA.js <==
// this code was generated using the rkwarddev package.
//perhaps don't make changes here, but in the rkwarddev script instead!

function preprocess(){
	// add requirements etc. here
	echo("require(mclust)\n");
}

function calculate(){
	// read in variables from dialog
	var vrslDtmtrxrd = getValue("vrsl_Dtmtrxrd");
	var chcRmvmssng = getValue("chc_Rmvmssng");
	var chcStdrdzvl = getValue("chc_Stdrdzvl");
	var spnMxnmbrfc = getValue("spn_Mxnmbrfc");
	var chcPltrslts = getValue("chc_Pltrslts");
	var svbSvrsltst = getValue("svb_Svrsltst");
	var radPlottype = getValue("rad_Plottype");

	// the R code to be evaluated
	if(chcRmvmssng) {
		echo("\t# Listwise removal of missings\n\t" + vrslDtmtrxrd + " <- na.omit(" + vrslDtmtrxrd + ")\n");
	} else {}
	if(chcStdrdzvl) {
		echo("\t# Standardizing values\n\t" + vrslDtmtrxrd + " <- scale(" + vrslDtmtrxrd + ")\n");
	} else {}
	echo("\t# Model based CA\n\tclust.m.result <- Mclust(data=" + vrslDtmtrxrd);
	if(spnMxnmbrfc != 9) {
		echo(",\n\t\tG=1:" + spnMxnmbrfc + "\n\t");
	} else {}
	echo(")\n\n");
}

function printout(){
	// all the real work is moved to a custom defined function doPrintout() below
	// true in this case means: We want all the headers that should be printed in the output:
	doPrintout(true);
}

function preview(){
	preprocess();
	calculate();
	doPrintout(false);
}

function doPrintout(full){
	// read in variables from dialog
	var vrslDtmtrxrd = getValue("vrsl_Dtmtrxrd");
	var chcRmvmssng = getValue("chc_Rmvmssng");
	var chcStdrdzvl = getValue("chc_Stdrdzvl");
	var spnMxnmbrfc = getValue("spn_Mxnmbrfc");
	var chcPltrslts = getValue("chc_Pltrslts");
	var svbSvrsltst = getValue("svb_Svrsltst");
	var radPlottype = getValue("rad_Plottype");

	// create the plot
	if(full) {
		echo("rk.header(\"Model based CA results\", level=1)\n");
	} else {}

	if(chcPltrslts) {
		if(full) {
	echo("rk.graph.on()\n");
} else {}
echo("\ttry({\n\t\tplot(clust.m.result,\n\t\t\tdata=" + vrslDtmtrxrd + ",\n\t\t\twhat=\"" + radPlottype + "\"");
echo(")\n\t})\n");
if(full) {
	echo("rk.graph.off()\nrk.print(clust.m.result)\n");
} else {}
	} else {}

	// left over from the printout function

	var svbSvrsltst = getValue("svb_Svrsltst");
	var svbSvrsltstActive = getValue("svb_Svrsltst.active");
	var svbSvrsltstParent = getValue("svb_Svrsltst.parent");
	if(svbSvrsltstActive) {
		echo("assign(\"" + svbSvrsltst + "\", clust.m.result, envir=" + svbSvrsltstParent + ")\n");
	} else {}


}
